@@ -1,26 +1,15 @@
-# -*- coding: utf-8 -*-
-from __future__ import absolute_import, print_function, division
 import itertools
-
+import sys
 
 import numpy as np
+import pytest
 
-
-from numcodecs.compat import PY2
 from numcodecs.pickles import Pickle
 from numcodecs.tests.common import (check_config, check_repr, check_encode_decode_array,
                                     check_backwards_compatibility, greetings)
 
 
-codecs = [
-    Pickle(protocol=0),
-    Pickle(protocol=1),
-    Pickle(protocol=2),
-]
-if not PY2:  # pragma: py2 no cover
-    codecs.append(Pickle(protocol=3))
-    codecs.append(Pickle(protocol=4))
-
+codecs = [Pickle(protocol=i) for i in range(5)]
 
 # object array with strings
 # object array with mix strings / nans
@@ -54,5 +43,7 @@ def test_repr():
     check_repr("Pickle(protocol=-1)")
 
 
+@pytest.mark.skipif(sys.byteorder != 'little',
+                    reason='Pickle does not restore byte orders')
 def test_backwards_compatibility():
     check_backwards_compatibility(Pickle.codec_id, arrays, codecs)
